contacts

package
v1.3.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 2, 2025 License: MIT Imports: 12 Imported by: 0

Documentation

Overview

Package contacts provides the ContactController for handling contact form submissions.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ContactController

type ContactController struct {
	APIWrapper *t.APIWrapper[ci.ContactForm]
	// contains filtered or unexported fields
}

func NewContactController

func NewContactController(properties map[string]any) *ContactController

func (*ContactController) GetContact

func (c *ContactController) GetContact(ctx *gin.Context)

@Summary Contact flow for messaging through Email or other channels @Description This endpoint handles the contact form submissions and sends messages through the appropriate channels. @Schemes http https @Tags contact @Accept json @Produce json @Success 200 {string} Message sent successfully @Router /contact [get]

func (*ContactController) GetContactForm

func (c *ContactController) GetContactForm(ctx *gin.Context)

@Summary Contact flow for messaging through Email or other channels @Description This endpoint handles the contact form submissions and sends messages through the appropriate channels. @Schemes http https @Tags contact @Accept json @Produce json @Success 200 {object} t.ContactForm @Router /contact/form [get]

func (*ContactController) GetContactFormByID

func (c *ContactController) GetContactFormByID(ctx *gin.Context)

@Summary Get contact form by ID @Description This endpoint retrieves a specific contact form submission by its ID. @Schemes http https @Tags contact @Accept json @Produce json @Success 200 {object} t.ContactForm @Router /contact/form/:id [get]

func (*ContactController) HandleContact

func (c *ContactController) HandleContact(ctx *gin.Context)

func (*ContactController) PostContact

func (c *ContactController) PostContact(ctx *gin.Context)

@Summary Contact flow for messaging through Email or other channels @Description This endpoint handles the contact form submissions and sends messages through the appropriate channels. @Schemes http https @Tags contact @Accept json @Produce json @Success 200 {string} Message sent successfully @Router /contact [post]

type SMTPConfig

type SMTPConfig struct {
	Host string
	Port string
	User string
	Pass string
}

Jump to